#! /usr/local/bin/perl
#
# GenWavs - Generate gauge sound files
#
# This program uses augen (from the autools port) to generate wave files.
# The wave files go with the JGauge scripts and are used as an audible gauge.
#
# Author:  Doug Lee
# See the bottom of this file for licensing information.
#
# Revision History:
#     08/09/03:  Initial version.
#     08/15/03:  Added New/Exp/Obs/Unr wavs and improved the original sounds.

# See genTone() for wave type and start phase.
# See genFile for duration, amplitude, and which tones go in the files.

# Start and end frequencies for the whole file set, in Hz
$startFreq = 220;
$endFreq = 880;
# Number of evenly-spaced sounds to generate, from startFreq to endFreq
# This is inclusive, hence the odd number of sounds.
$nsounds=101;
# Output file name prefix (full name = ${fprefix}<n>.wav)
$fprefix="gauge";

# Number of octaves in the frequency range (possibly non-integral)
my $noctaves = ($endFreq / $startFreq) /2;
# Number of notes per octave (possibly non-integral)
my $npo = ($nsounds-1) / $noctaves;

for(my $i=0; $i<$nsounds; $i++) {
  $fc = $startFreq * (2 ** ($i / $npo));
  genFile( sprintf("$fprefix%-3d", $i), $fc);
}
genFile($fprefix . "New", "new");
genFile($fprefix . "Exp", "exp");
genFile($fprefix . "Obs", "obs");
genFile($fprefix . "Unr", "unr");
exit 0;

sub genFile {
# Generate one file--or rather make augen do it.
  my($fname, $fc) = @_;
  $fname =~ s/\s+$//;
  print "Generating $fname ...\n";
  open(FH, "|augen -s 11025 -ea wav -g - -o $fname")
      ||die "Can't generate $fname; $!\n";
  select(FH);
  if ($fc =~ /^\d/) {
    genTone($fc, 0.05, 0.3);
    genBorders();
  } elsif ($fc =~ /new/i) {
    my $sf = ($startFreq+$endFreq) /4;
    my $ef = ($startFreq+$endFreq) *3 /4;
    printf("t 0 0.05 %9.4f %9.4f 90 0.3 0.3\n",
        $sf, $ef);
    genBorders();
  } elsif ($fc =~ /exp/i) {
    my $sf = ($startFreq+$endFreq) *3 /4;
    my $ef = ($startFreq+$endFreq) /4;
    printf("t 0 0P.05 %9.4f %9.4f 90 0.3 0.3\n",
        $sf, $ef);
    genBorders();
  } elsif ($fc =~ /obs/i) {
    printf("n 0 0.05 0.1 0.1\n");
    genBorders();
  } elsif ($fc =~ /unr/i) {
    printf("n 0 0.05 0.1 0.1\n");
  }
  close(FH);  # waits for generation to complete
  select(STDOUT);
  die "Generation of $fname failed.\n" if !-e "$fname.wav";
}

sub genBorders {
  genTone($startFreq, 0.05, 0.08);
  genTone($endFreq, 0.05, 0.08);
}

sub genTone {
# Produce the directions needed for one tone.
  my($fc, $nsec, $amp) = @_;
  # waveType T0 T1 fc0 fc1 startPhaseDeg amp0 amp1
  printf("t 0 %4.2f %9.4f %9.4f 90 %4.2f %4.2f\n",
      $nsec, $fc, $fc, $amp, $amp);
}

__END__
/*
Copyright (c) 2006-2009, Doug Lee and SSB BART Group

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice,
  this list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* The names of the copyright holders and contributors may not be used to
  endorse or promote products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
